@@ -14,7 +14,7 @@
 """
 
 __author__ = "Guewen Baconnier <guewen.baconnier@gmail.com>"
-__version__ = "0.4.0"
+__version__ = "0.5.0"
 
 import urllib
 import warnings
@@ -194,16 +194,16 @@ class PrestaShopWebService(object):
 
         return parsed_content
 
-    def _validate(self, options):
+    def _validate_query_options(self, options):
         """
         Check options against supported options
-        (reference : http://doc.prestashop.com/display/PS14/Cheat+Sheet_+Concepts+Outlined+in+this+Tutorial)
+        (reference : http://doc.prestashop.com/display/PS14/Cheat-sheet+-+Concepts+outlined+in+this+tutorial)
         @param options: dict of options to use for the request
         @return: True if valid, else raise an error PrestaShopWebServiceError
         """
         if not isinstance(options, dict):
             raise PrestaShopWebServiceError('Parameters must be a instance of dict')
-        supported = ('filter', 'display', 'sort', 'limit', 'schema')
+        supported = ('filter', 'display', 'sort', 'limit', 'schema', 'date')
         # filter[firstname] (as e.g.) is allowed, so check only the part before a [
         unsupported = set([param.split('[')[0] for param in options]).difference(supported)
         if unsupported:
@@ -211,6 +211,9 @@ class PrestaShopWebService(object):
             % (', '.join(tuple(unsupported)),))
         return True
 
+    # _validate method is deprecated
+    _validate = _validate_query_options
+
     def _options_to_querystring(self, options):
         """
         Translate the dict of options to a url form
@@ -278,7 +281,7 @@ class PrestaShopWebService(object):
         if resource_id is not None:
             full_url += "/%s" % (resource_id,)
         if options is not None:
-            self._validate(options)
+            self._validate_query_options(options)
             full_url += "?%s" % (self._options_to_querystring(options),)
         return self.get_with_url(full_url)
 
@@ -304,7 +307,7 @@ class PrestaShopWebService(object):
         if resource_id is not None:
             full_url += "/%s" % (resource_id,)
         if options is not None:
-            self._validate(options)
+            self._validate_query_options(options)
             full_url += "?%s" % (self._options_to_querystring(options),)
         return self.head_with_url(full_url)
 
@@ -403,14 +406,14 @@ class PrestaShopWebServiceDict(PrestaShopWebService):
         # for zero resource :
         # {'addresses': ''}
         response = super(PrestaShopWebServiceDict, self).\
-                    get(resource, options=options)
+                    search(resource, options=options)
 
         elems = dive(response, level=2)
         # when there is only 1 resource, we do not have a list in the response
         if not elems:
             return []
         elif isinstance(elems, list):
-            ids = [int(attr['id']) for attr in [elem['attrs'] for elem in elems]]
+            ids = [int(elem['attrs']['id']) for elem in elems]
         else:
             ids = [int(elems['attrs']['id'])]
         return ids
